"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const node_fs_1 = tslib_1.__importDefault(require("node:fs"));
const template_file_1 = require("template-file");
const bootstrapTemplate = `module "bootstrap" {
  source = "github.com/markcallen/aws-cld//bootstrap/"
  project = "{{ project }}"
}

output "project" {
  value = module.bootstrap.project_name
}
`;
class Bootstrap extends core_1.Command {
    async run() {
        const { flags } = await this.parse(Bootstrap);
        const { directory, project } = flags;
        if (node_fs_1.default.existsSync(directory)) {
            this.error(`${directory} exists`);
        }
        node_fs_1.default.mkdirSync(directory);
        // Make the boostrap, infra and env directories
        node_fs_1.default.mkdirSync(`${directory}/bootstrap`);
        node_fs_1.default.mkdirSync(`${directory}/infra`);
        node_fs_1.default.mkdirSync(`${directory}/env`);
        const bootstrapData = { project };
        node_fs_1.default.writeFileSync(`${directory}/bootstrap/main.tf`, (0, template_file_1.render)(bootstrapTemplate, bootstrapData));
        // TODO: add in terraform init, plan and apply
    }
}
exports.default = Bootstrap;
Bootstrap.description = 'AWS quick utilities';
Bootstrap.examples = [
    `$ <%= config.bin %> <%= command.id %>
`
];
Bootstrap.flags = {
    directory: core_1.Flags.string({ char: 'd', required: true }),
    project: core_1.Flags.string({ char: 'p', required: true })
};
